package org.vector.fastjson.demo;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

/**
 * json字符串解析为JSONObject和JSONArray
 * 如果解析json字符串，又不想创建太多的javabean的时候就可以用这些
 * api，方便数据的获取和处理
 * @author Vector
 */
/*
 * FastJson API
 * 
 * Object parse(String text)	通用方法
 * 
 * JSONObject parseObject(String text)
 * JSONArray parseArray(String text)
 */
public class Trans2JSONObjArr {
	
	public static void main(String[] args) {
		
		parseStringToJsonObject();//1.JSONObject[ok]
		parseStringToJsonArray();//2.JSONArray[ok]
		parseStringToJsonArrayOrJsonObject();//3.JSONArray or JSONObject[ok]
		
	}
	
	/**
	 * Object parse(String text)的使用[ok]
	 */
	private static void parseStringToJsonArrayOrJsonObject() {
		System.out.println("parseStringToJsonArrayOrJsonObject-------------------------------------start");
		
		String bean_json = "{'id':1,'isdead':true,'birth':1473153533840,'name':'赵飞','age':68}";
		Object object1 = JSON.parse(bean_json);//object可能是JSONArray，可能是JSONObject
		
		if(object1 instanceof JSONArray){//使用instanceof进行判断
			System.out.println("object1 is JSONArray");
			JSONArray array = (JSONArray)object1;
			//继续使用JSONArray的API操作吧
		}else{
			System.out.println("object1 is not JSONArray");
		}
		
		
		String array_json = "[{'id':1,'isdead':true,'birth':'2016-09-01 17:32:22','name':'张飞','age':68},{'id':2,'isdead':false,'birth':'2000-09-01 00:32:22','name':'赵云','age':78}]";
		Object object2 = JSON.parse(array_json);//object可能是JSONArray，可能是JSONObject
		if(object2 instanceof JSONObject){//使用instanceof进行判断
			System.out.println("object2 is JSONObject");
			JSONObject array = (JSONObject)object1;//可以使用JSONObject的api进行操作了
			//继续使用JSONObject的API操作吧
		}else{
			System.out.println("object2 is not JSONObject");
		}
		
		System.out.println("parseStringToJsonArrayOrJsonObject-------------------------------------end\n");
	}


	/**
	 * JSONArray parseArray(String text)的使用[ok]
	 */
	private static void parseStringToJsonArray() {
		System.out.println("parseArray-------------------------------------start");
//		date类型解析支持毫秒值，日期字符串，日期时间字符串
			String jsonStr1 = "[{'id':1,'isdead':true,'birth':'2016-09-01 17:32:22','name':'张飞','age':68},{'id':2,'isdead':false,'birth':'2000-09-01 00:32:22','name':'赵云','age':78}]";
//			String jsonStr1 = "[{'id':1,'isdead':true,'birth':'2016-09-01','name':'张飞','age':68},{'id':2,'isdead':false,'birth':'2000-09-01 00:32:22','name':'赵云','age':78}]";
//			String jsonStr1 = "[{'id':1,'isdead':true,'birth':'1473153533840','name':'张飞','age':68},{'id':2,'isdead':false,'birth':'1471153533840','name':'赵云','age':78}]";

			JSONArray array = JSON.parseArray(jsonStr1);//转为对应的JSONObject对象，可使用JSONObject的一些api
			
			//继续获取下一层Array
//			array.getJSONArray(index)
			//继续获取下一层JsonObject
//			array.getJSONObject(index)//
			//继续获取下一层属性，并转为bean对象
//			array.getObject(index, clazz)
			User u = array.getObject(0, User.class);
			System.out.println("u="+u);
			
			for (Object object : array) {
				System.out.println("object="+object);
			}
			System.out.println("parseArray-------------------------------------end\n");
	}


	/**
	 * JSONObject parseObject(String text)的使用[ok]
	 */
	private static void parseStringToJsonObject() {
		System.out.println("parseObject-------------------------------------start");
		//知道它肯定是一个对象数据，那么可以这么用
		String bean_json = "{'id':1,'isdead':true,'birth':1473153533840,'name':'赵飞','age':68}";
//		String jsonStr1 = "{'id':1,'isdead':true,'birth':'2016-09-01','name':'赵飞','age':68}";
//		String jsonStr1 = "{'id':1,'isdead':true,'birth':1473153533840,'name':'赵飞','age':68}";
		
		JSONObject jsonObj = JSON.parseObject(bean_json);//转为对应的JSONObject对象，可使用JSONObject的一些api
		System.out.println("id="+jsonObj.getLongValue("id"));
		System.out.println("name="+jsonObj.getString("name"));
		System.out.println("age="+jsonObj.getIntValue("age"));
		System.out.println("birth="+jsonObj.getDate("birth"));
		System.out.println("isdead="+jsonObj.getBooleanValue("isdead"));
//		如果有其他嵌套属性可以继续这么取
//		System.out.println(jsonObj.getJSONArray(""));
//		System.out.println(jsonObj.getJSONObject(""));
		System.out.println("parseObject-------------------------------------end\n");
	}

}
